@@ -159,6 +159,9 @@ class ClientOptions(BaseModel):
     else:
         from pydantic import validator
 
+        class Config:
+            json_encoders = {timedelta: lambda v: int(v.total_seconds()) if v else None}
+
         @validator("request_timeout", "update_interval", pre=True)
         def parse_timedelta(cls, v):
             if v is None or isinstance(v, timedelta):
@@ -202,6 +205,7 @@ class BooleanEvaluationResponse(BaseModel):
     reason: str  #: Reason for the evaluation result.
     request_duration_millis: float  #: Duration of the request in milliseconds.
     timestamp: str  #: Timestamp of the evaluation.
+    segment_keys: List[str]  #: List of matched segment keys.
 
 
 class ErrorEvaluationResponse(BaseModel):
